@@ -1,6 +1,6 @@
 ###############################################################################
 #
-#   Copyright: (c) 2017-2020 Carlo Sbraccia
+#   Copyright: (c) 2017-2021 Carlo Sbraccia
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -110,13 +110,22 @@ def get_address_port_hostname(sockets, dns_suffix):
 
 ###############################################################################
 class DataServer(tornado.tcpserver.TCPServer):
+    """
+    NB: a roundtrip should take at most blp_timeout + 2*tcp_timeout + cpu time
+    """
     # -------------------------------------------------------------------------
-    def __init__(self, logger=None, nthreads=10, blp_timeout=1, tcp_timeout=5):
+    def __init__(
+        self,
+        logger=None,
+        nthreads=10,
+        blp_timeout=500,  # milliseconds
+        tcp_timeout=100   # milliseconds
+    ):
         super().__init__()
         self.logger = logger or logging.getLogger(__name__)
         self.tpool = futures.ThreadPoolExecutor(max_workers=nthreads)
-        self.blp_timeout = blp_timeout * 1000  # seconds to milliseconds
-        self.tcp_timeout = datetime.timedelta(seconds=tcp_timeout)
+        self.blp_timeout = blp_timeout
+        self.tcp_timeout = datetime.timedelta(milliseconds=tcp_timeout)
         self.bdp_clients = cycle([
             bbg_api.bdp_client() for thread in range(nthreads)])
 
@@ -220,42 +229,32 @@ class DataServer(tornado.tcpserver.TCPServer):
         #     here 'in-place'
         request["overrides"] = json.loads(request["overrides"])
 
-        # --- try processing the request for a maximum of 5 times using
-        #     geometrically increasing timeouts
-        timeout = self.blp_timeout
-        for _ in range(5):
-            try:
-                if request_type == "BDP":
-                    # --- pull a bbg-bdp client from the clients pool
-                    clt = next(self.bdp_clients)
-                    resp = await self.thrd_async(
-                                bdp_request, clt, timeout, request)
-                else:
-                    resp = await self.thrd_async(bdh_request, timeout, request)
-                break
-            except TimeoutError:
-                timeout *= 2
-                self.logger.debug(
-                    f"request {request!s} timeout increased to {timeout:f}ms")
-            except DatafeedFatal as err:
-                # --- unrecoverable bloomberg error: don't send a reply so that
-                #     the datafeed router knows this server is currently unable
-                #     to respond to requests.
-                self.logger.error(err, exc_info=True)
-                return
-
-        else:
-            timeout /= 2
+        try:
+            if request_type == "BDP":
+                # --- pull a bbg-bdp client from the clients pool
+                clt = next(self.bdp_clients)
+                resp = await self.thrd_async(
+                    bdp_request, clt, self.blp_timeout, request)
+            else:
+                resp = await self.thrd_async(
+                    bdh_request, self.blp_timeout, request)
+        except TimeoutError:
+            err_msg = \
+                f"bloomberg request timed out after {self.blp_timeout!s} ms"
             resp = {
                 "type": "TimeoutError",
-                "payload": (
-                    "request timed out after 5 attempts with a final "
-                    f"timeout of {timeout!s} milliseconds"),
+                "payload": err_msg
             }
-            # --- try re-initializing clients
-            for clt in self.bdp_clients:
-                clt.stop()
-                clt.initialize_session_and_service()
+            # # --- try re-initializing clients
+            # for clt in self.bdp_clients:
+            #     clt.stop()
+            #     clt.initialize_session_and_service()
+        except DatafeedFatal as err:
+            # --- unrecoverable bloomberg error: don't send a reply so that
+            #     the datafeed router knows this server is currently unable
+            #     to respond to requests.
+            self.logger.error(err, exc_info=True)
+            return
 
         resp = process_response(resp)
         resp = encode_message(resp)
